@@ -20,7 +20,9 @@ package org.apache.openmeetings.db.dao.user;
 
 import static java.util.UUID.randomUUID;
 import static org.apache.openmeetings.db.util.DaoHelper.fillLazy;
+import static org.apache.openmeetings.db.util.DaoHelper.getRoot;
 import static org.apache.openmeetings.db.util.DaoHelper.getStringParam;
+import static org.apache.openmeetings.db.util.DaoHelper.only;
 import static org.apache.openmeetings.db.util.DaoHelper.setLimits;
 import static org.apache.openmeetings.db.util.DaoHelper.single;
 import static org.apache.openmeetings.db.util.TimezoneUtil.getTimeZone;
@@ -30,30 +32,35 @@ import static org.apache.openmeetings.util.OpenmeetingsVariables.getDefaultTimez
 import static org.apache.openmeetings.util.OpenmeetingsVariables.getMinLoginLength;
 
 import java.io.File;
+import java.io.IOException;
+import java.nio.file.Files;
 import java.security.NoSuchAlgorithmException;
 import java.time.LocalDate;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Date;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Locale;
-import java.util.Map;
 import java.util.Set;
 
-import javax.persistence.EntityManager;
-import javax.persistence.PersistenceContext;
-import javax.persistence.TypedQuery;
+import jakarta.persistence.EntityManager;
+import jakarta.persistence.PersistenceContext;
+import jakarta.persistence.criteria.CriteriaBuilder;
+import jakarta.persistence.criteria.CriteriaQuery;
+import jakarta.persistence.criteria.JoinType;
+import jakarta.persistence.criteria.Predicate;
+import jakarta.persistence.criteria.Root;
+import jakarta.persistence.criteria.Subquery;
 
 import org.apache.commons.lang3.StringUtils;
 import org.apache.openmeetings.db.dao.IGroupAdminDataProviderDao;
 import org.apache.openmeetings.db.dao.label.LabelDao;
 import org.apache.openmeetings.db.entity.user.Address;
 import org.apache.openmeetings.db.entity.user.AsteriskSipUser;
+import org.apache.openmeetings.db.entity.user.GroupUser;
 import org.apache.openmeetings.db.entity.user.User;
 import org.apache.openmeetings.db.entity.user.User.Right;
-import org.apache.openmeetings.db.entity.user.User.Salutation;
 import org.apache.openmeetings.db.entity.user.User.Type;
 import org.apache.openmeetings.db.util.AuthLevelUtil;
 import org.apache.openmeetings.db.util.DaoHelper;
@@ -61,6 +68,7 @@ import org.apache.openmeetings.util.OmException;
 import org.apache.openmeetings.util.OmFileHelper;
 import org.apache.openmeetings.util.crypt.CryptProvider;
 import org.apache.openmeetings.util.crypt.ICrypt;
+import org.apache.wicket.extensions.markup.html.repeater.util.SortParam;
 import org.apache.wicket.util.string.Strings;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -70,7 +78,7 @@ import org.springframework.transaction.annotation.Transactional;
 /**
  * CRUD operations for {@link User}
  *
- * @author swagner, solomax, vasya
+ * @author swagner, vasya
  *
  */
 @Repository
@@ -78,9 +86,11 @@ import org.springframework.transaction.annotation.Transactional;
 public class UserDao implements IGroupAdminDataProviderDao<User> {
 	private static final Logger log = LoggerFactory.getLogger(UserDao.class);
 	private static final String PARAM_EMAIL = "email";
-	private static final String[] searchFields = {"lastname", "firstname", "login", "address.email", "address.town"};
-	public static final String FETCH_GROUP_GROUP = "groupUsers";
-	public static final String FETCH_GROUP_BACKUP = "backupexport";
+	private static final List<String> searchFields = List.of("lastname", "firstname", "login", "address.email", "address.town");
+	private static final List<String> guSearchFields = searchFields.stream().map(f -> "user." + f).toList();
+	private static final String FIELD_GROUP = "group";
+	public static final String FETCH_GROUP_GROUP = "Group_Users";
+	public static final String FETCH_GROUP_BACKUP = "Backup_Export";
 
 	@PersistenceContext
 	private EntityManager em;
@@ -101,11 +111,9 @@ public class UserDao implements IGroupAdminDataProviderDao<User> {
 	 */
 	public static User getNewUserInstance(User currentUser) {
 		User user = new User();
-		user.setSalutation(Salutation.MR);
 		user.setRights(getDefaultRights());
 		user.setLanguageId(getDefaultLang());
 		user.setTimeZoneId(getTimeZone(currentUser).getID());
-		user.setAge(LocalDate.now());
 		user.setLastlogin(new Date());
 		Address address = new Address();
 		address.setCountry(Locale.getDefault().getCountry());
@@ -123,81 +131,102 @@ public class UserDao implements IGroupAdminDataProviderDao<User> {
 				, first, count).getResultList();
 	}
 
-	private static String getAdditionalJoin(boolean filterContacts) {
-		return filterContacts ? "LEFT JOIN u.groupUsers ou" : null;
+	private Predicate getContactsFilter(CriteriaBuilder builder, CriteriaQuery<?> query) {
+		Root<User> root = getRoot(query, User.class);
+		return builder.notEqual(root.get("type"), Type.CONTACT);
 	}
 
-	private static String getAdditionalWhere(boolean excludeContacts, Map<String, Object> params) {
-		if (excludeContacts) {
-			params.put("contact", Type.CONTACT);
-			return "u.type <> :contact";
-		}
-		return null;
+	private Predicate getOwnerContactsFilter(Long ownerId, CriteriaBuilder builder, CriteriaQuery<?> query) {
+		Root<User> root = getRoot(query, User.class);
+		root.join("groupUsers", JoinType.LEFT);
+
+		Subquery<Long> subquery = query.subquery(Long.class);
+		Root<GroupUser> subRoot = subquery.from(GroupUser.class);
+		subquery.select(subRoot.get(FIELD_GROUP).get("id"));
+		subquery.where(builder.equal(subRoot.get("user").get("id"), ownerId));
+		return builder.or(
+				builder.and(builder.notEqual(root.get("type"), Type.CONTACT), root.get("groupUsers").get(FIELD_GROUP).get("id").in(subquery))
+				, builder.and(builder.equal(root.get("type"), Type.CONTACT), builder.equal(root.get("ownerId"), ownerId))
+				);
 	}
 
-	private static String getAdditionalWhere(boolean filterContacts, Long ownerId, Map<String, Object> params) {
+	private List<User> get(String search, Long start, Long count, SortParam<String> sort, boolean filterContacts, Long currentUserId, boolean filterDeleted) {
 		if (filterContacts) {
-			params.put("ownerId", ownerId);
-			params.put("contact", Type.CONTACT);
-			return "((u.type <> :contact AND ou.group.id IN (SELECT ou.group.id FROM GroupUser ou WHERE ou.user.id = :ownerId)) "
-				+ "OR (u.type = :contact AND u.ownerId = :ownerId))";
+			return DaoHelper.get(em, User.class
+					, true, search, searchFields, true
+					, (b, q) -> getOwnerContactsFilter(currentUserId, b, q)
+					, sort, start, count);
+		} else {
+			return DaoHelper.get(em, User.class, false, search, searchFields, filterDeleted
+					, null, sort, start, count);
 		}
-		return null;
-	}
-
-	private static void setAdditionalParams(TypedQuery<?> q, Map<String, Object> params) {
-		for (Map.Entry<String, Object> me: params.entrySet()) {
-			q.setParameter(me.getKey(), me.getValue());
-		}
-	}
-
-	private List<User> get(String search, Long start, Long count, String order, boolean filterContacts, Long currentUserId, boolean filterDeleted) {
-		Map<String, Object> params = new HashMap<>();
-		TypedQuery<User> q = em.createQuery(DaoHelper.getSearchQuery("User", "u", getAdditionalJoin(filterContacts), search, true, filterDeleted, false
-				, getAdditionalWhere(filterContacts, currentUserId, params), order, searchFields), User.class);
-		setAdditionalParams(setLimits(q, start, count), params);
-		return q.getResultList();
 	}
 
 	// This is AdminDao method
-	public List<User> get(String search, boolean excludeContacts, long first, long count) {
-		Map<String, Object> params = new HashMap<>();
-		TypedQuery<User> q = em.createQuery(DaoHelper.getSearchQuery("User", "u", null, search, true, true, false
-				, getAdditionalWhere(excludeContacts, params), null, searchFields), User.class);
-		setAdditionalParams(setLimits(q, first, count), params);
-		return q.getResultList();
+	public List<User> get(String search, boolean excludeContacts, long start, long count) {
+		return DaoHelper.get(em, User.class, false, search, searchFields, true
+				, excludeContacts ? this::getContactsFilter : null
+				, null, start, count);
 	}
 
-	public List<User> get(String search, long start, long count, String sort, boolean filterContacts, Long currentUserId) {
+	public List<User> get(String search, long start, long count, SortParam<String> sort, boolean filterContacts, Long currentUserId) {
 		return get(search, start, count, sort, filterContacts, currentUserId, true);
 	}
 
 	@Override
-	public List<User> adminGet(String search, long start, long count, String order) {
-		return get(search, start, count, order, false, null, false);
+	public List<User> adminGet(String search, long start, long count, SortParam<String> sort) {
+		return get(search, start, count, sort, false, null, false);
+	}
+
+	private Predicate getAdminFilter(Long adminId, CriteriaBuilder builder, CriteriaQuery<?> query) {
+		Root<GroupUser> root = getRoot(query, GroupUser.class);
+		return builder.in(root.get(FIELD_GROUP).get("id")).value(DaoHelper.groupAdminQuery(adminId, builder, query));
 	}
 
 	@Override
-	public List<User> adminGet(String search, Long adminId, long start, long count, String order) {
-		TypedQuery<User> q = em.createQuery(DaoHelper.getSearchQuery("GroupUser gu, IN(gu.user)", "u", null, search, true, false, false
-				, "gu.group.id IN (SELECT gu1.group.id FROM GroupUser gu1 WHERE gu1.moderator = true AND gu1.user.id = :adminId)", order, searchFields), User.class);
-		q.setParameter("adminId", adminId);
-		return setLimits(q, start, count).getResultList();
+	public List<User> adminGet(String search, Long adminId, long start, long count, SortParam<String> sort) {
+		return DaoHelper.get(em, GroupUser.class, User.class
+				, (builder, root) -> root.get("user")
+				, true, search, guSearchFields, false
+				, (b, q) -> getAdminFilter(adminId, b, q)
+				, sort, start, count);
+	}
+
+	private Predicate getProfileFilter(Long userId, String userOffers, String userSearches, CriteriaBuilder builder, CriteriaQuery<?> query) {
+		Root<User> root = getRoot(query, User.class);
+		Predicate result = getOwnerContactsFilter(userId, builder, query);
+		if (!Strings.isEmpty(userOffers)) {
+			result = builder.and(result, DaoHelper.like("userOffers", getStringParam(userOffers), builder, root));
+		}
+		if (!Strings.isEmpty(userSearches)) {
+			result = builder.and(result, DaoHelper.like("userSearches", getStringParam(userSearches), builder, root));
+		}
+		return result;
+	}
+
+	public List<User> searchUserProfile(Long userId, String search, String userOffers, String userSearches, SortParam<String> sort, long start, long count) {
+		return DaoHelper.get(em, User.class
+				, true, search, searchFields, true
+				, (b, q) -> getProfileFilter(userId, userOffers, userSearches, b, q)
+				, sort, start, count);
 	}
 
 	private long count(String search, boolean filterContacts, Long currentUserId, boolean filterDeleted) {
-		Map<String, Object> params = new HashMap<>();
-		TypedQuery<Long> q = em.createQuery(DaoHelper.getSearchQuery("User", "u", getAdditionalJoin(filterContacts), search, true, filterDeleted, true
-				, getAdditionalWhere(filterContacts, currentUserId, params), null, searchFields), Long.class);
-		setAdditionalParams(q, params);
-		return q.getSingleResult();
+		if (filterContacts) {
+			return DaoHelper.count(em, User.class
+					, CriteriaBuilder::countDistinct
+					, search, searchFields, filterDeleted
+					, (b, q) -> getOwnerContactsFilter(currentUserId, b, q));
+		} else {
+			return DaoHelper.count(em, User.class, search, searchFields, filterDeleted
+					, null);
+		}
 	}
 
 	@Override
 	public long count() {
-		// get all users
-		TypedQuery<Long> q = em.createNamedQuery("countNondeletedUsers", Long.class);
-		return q.getSingleResult();
+		return em.createNamedQuery("countNondeletedUsers", Long.class)
+				.getSingleResult();
 	}
 
 	@Override
@@ -220,10 +249,17 @@ public class UserDao implements IGroupAdminDataProviderDao<User> {
 
 	@Override
 	public long adminCount(String search, Long adminId) {
-		TypedQuery<Long> q = em.createQuery(DaoHelper.getSearchQuery("GroupUser gu, IN(gu.user)", "u", null, search, true, false, true
-				, "gu.group.id IN (SELECT gu1.group.id FROM GroupUser gu1 WHERE gu1.moderator = true AND gu1.user.id = :adminId)", null, searchFields), Long.class);
-		q.setParameter("adminId", adminId);
-		return q.getSingleResult();
+		return DaoHelper.count(em, GroupUser.class
+				, (builder, root) -> builder.countDistinct(root.get("user"))
+				, search, guSearchFields, false
+				, (b, q) -> getAdminFilter(adminId, b, q));
+	}
+
+	public Long searchCountUserProfile(Long userId, String search, String userOffers, String userSearches) {
+		return DaoHelper.count(em, User.class
+				, CriteriaBuilder::countDistinct
+				, search, searchFields, true
+				, (b, q) -> getProfileFilter(userId, userOffers, userSearches, b, q));
 	}
 
 	@Override
@@ -322,7 +358,7 @@ public class UserDao implements IGroupAdminDataProviderDao<User> {
 			u.setAddress(new Address());
 			u.setAge(LocalDate.now());
 			u.setExternalId(null);
-			final String purged = String.format("Purged %s", randomUUID());
+			final String purged = "Purged " + randomUUID();
 			u.setFirstname(purged);
 			u.setLastname(purged);
 			u.setLogin(purged);
@@ -340,7 +376,11 @@ public class UserDao implements IGroupAdminDataProviderDao<User> {
 			update(u, userId);
 			// this should be last action, so file will be deleted in case there were no errors
 			if (pic != null) {
-				pic.delete();
+				try {
+					Files.deleteIfExists(pic.toPath());
+				} catch (IOException e) {
+					log.error("Unexpected exception while delete pic");
+				}
 			}
 		}
 	}
@@ -394,7 +434,8 @@ public class UserDao implements IGroupAdminDataProviderDao<User> {
 		return !Strings.isEmpty(login) && login.length() >= getMinLoginLength();
 	}
 
-	public User getByLogin(String login, Type type, Long domainId) {
+	public User getByLogin(String inLogin, Type type, Long domainId) {
+		String login = inLogin == null ? null : inLogin.trim().toLowerCase(Locale.ROOT);
 		return single(fillLazy(em
 				, oem -> oem.createNamedQuery("getUserByLogin", User.class)
 					.setParameter("login", login)
@@ -407,7 +448,8 @@ public class UserDao implements IGroupAdminDataProviderDao<User> {
 		return getByEmail(email, User.Type.USER, null);
 	}
 
-	public User getByEmail(String email, User.Type type, Long domainId) {
+	public User getByEmail(String inEmail, User.Type type, Long domainId) {
+		String email = inEmail == null ? null : inEmail.trim().toLowerCase(Locale.ROOT);
 		return single(fillLazy(em
 				, oem -> oem.createNamedQuery("getUserByEmail", User.class)
 					.setParameter(PARAM_EMAIL, email)
@@ -434,9 +476,9 @@ public class UserDao implements IGroupAdminDataProviderDao<User> {
 	public Long selectMaxFromUsersWithSearch(String search) {
 		try {
 			// get all users
-			TypedQuery<Long> query = em.createNamedQuery("selectMaxFromUsersWithSearch", Long.class);
-			query.setParameter("search", StringUtils.lowerCase(search, Locale.ROOT));
-			List<Long> ll = query.getResultList();
+			List<Long> ll = em.createNamedQuery("selectMaxFromUsersWithSearch", Long.class)
+					.setParameter("search", StringUtils.lowerCase(search, Locale.ROOT))
+					.getResultList();
 			log.info("selectMaxFromUsers {}", ll.get(0));
 			return ll.get(0);
 		} catch (Exception ex2) {
@@ -453,12 +495,8 @@ public class UserDao implements IGroupAdminDataProviderDao<User> {
 	 * @return <code>true</code> if entered password is correct
 	 */
 	public boolean verifyPassword(Long userId, String password) {
-		List<String> l = em.createNamedQuery("getPassword", String.class)
-			.setParameter(PARAM_USER_ID, userId).getResultList();
-		if (l == null || l.size() != 1) {
-			return false;
-		}
-		String hash = l.get(0);
+		String hash = only(em.createNamedQuery("getPassword", String.class)
+				.setParameter(PARAM_USER_ID, userId).getResultList());
 		ICrypt crypt = CryptProvider.get();
 		if (crypt.verify(password, hash)) {
 			return true;
@@ -524,48 +562,6 @@ public class UserDao implements IGroupAdminDataProviderDao<User> {
 				, FETCH_GROUP_GROUP));
 	}
 
-	private <T> TypedQuery<T> getUserProfileQuery(Class<T> clazz, Long userId, String text, String offers, String search, String orderBy, boolean asc) {
-		Map<String, Object> params = new HashMap<>();
-		boolean filterContacts = true;
-		boolean count = clazz.isAssignableFrom(Long.class);
-
-		StringBuilder sb = new StringBuilder("SELECT ");
-		sb.append(count ? "COUNT(" : "").append("DISTINCT u").append(count ? ") " : " ")
-			.append("FROM User u ").append(getAdditionalJoin(filterContacts)).append(" WHERE u.deleted = false AND ")
-			.append(getAdditionalWhere(filterContacts, userId, params));
-		if (!Strings.isEmpty(offers)) {
-			sb.append(" AND (LOWER(u.userOffers) LIKE :userOffers) ");
-			params.put("userOffers", getStringParam(offers));
-		}
-		if (!Strings.isEmpty(search)) {
-			sb.append(" AND (LOWER(u.userSearchs) LIKE :userSearchs) ");
-			params.put("userSearchs", getStringParam(search));
-		}
-		if (!Strings.isEmpty(text)) {
-			sb.append(" AND (LOWER(u.login) LIKE :search ")
-				.append("OR LOWER(u.firstname) LIKE :search ")
-				.append("OR LOWER(u.lastname) LIKE :search ")
-				.append("OR LOWER(u.address.email) LIKE :search ")
-				.append("OR LOWER(u.address.town) LIKE :search " + ") ");
-			params.put("search", getStringParam(text));
-		}
-		if (!count && !Strings.isEmpty(orderBy)) {
-			sb.append(" ORDER BY ").append(orderBy).append(asc ? " ASC" : " DESC");
-		}
-		TypedQuery<T> query = em.createQuery(sb.toString(), clazz);
-		setAdditionalParams(query, params);
-		return query;
-	}
-
-	public List<User> searchUserProfile(Long userId, String text, String offers, String search, String orderBy, long start, long max, boolean asc) {
-		return setLimits(getUserProfileQuery(User.class, userId, text, offers, search, orderBy, asc)
-				, start, max).getResultList();
-	}
-
-	public Long searchCountUserProfile(Long userId, String text, String offers, String search) {
-		return getUserProfileQuery(Long.class, userId, text, offers, search, null, false).getSingleResult();
-	}
-
 	public User getExternalUser(String extId, String extType) {
 		return single(fillLazy(em
 				, oem -> oem.createNamedQuery("getExternalUser", User.class)
@@ -576,8 +572,8 @@ public class UserDao implements IGroupAdminDataProviderDao<User> {
 	}
 
 	@Override
-	public List<User> get(String search, long start, long count, String order) {
-		return get(search, start, count, order, false, Long.valueOf(-1));
+	public List<User> get(String search, long start, long count, SortParam<String> sort) {
+		return get(search, start, count, sort, false, Long.valueOf(-1));
 	}
 
 	public Set<Right> getRights(Long id) {
@@ -602,12 +598,13 @@ public class UserDao implements IGroupAdminDataProviderDao<User> {
 	/**
 	 * login logic
 	 *
-	 * @param userOrEmail - login or email of the user being tested
+	 * @param inUserOrEmail - login or email of the user being tested
 	 * @param userpass - password of the user being tested
 	 * @return User object in case of successful login
 	 * @throws OmException in case of any issue
 	 */
-	public User login(String userOrEmail, String userpass) throws OmException {
+	public User login(String inUserOrEmail, String userpass) throws OmException {
+		String userOrEmail = inUserOrEmail == null ? null : inUserOrEmail.trim().toLowerCase(Locale.ROOT);
 		List<User> users = em.createNamedQuery("getUserByLoginOrEmail", User.class)
 				.setParameter("userOrEmail", userOrEmail)
 				.setParameter("type", Type.USER)
@@ -616,7 +613,7 @@ public class UserDao implements IGroupAdminDataProviderDao<User> {
 		log.debug("login:: {} users were found", users.size());
 
 		if (users.isEmpty()) {
-			log.debug("No users was found: {}", userOrEmail);
+			log.debug("No users were found: {}", userOrEmail == null ? null : userOrEmail.replaceAll("\\p{C}", "?"));
 			return null;
 		}
 		User u = users.get(0);
