@@ -43,28 +43,30 @@ import org.apache.wicket.markup.html.basic.Label;
 import org.apache.wicket.markup.html.panel.Panel;
 import org.apache.wicket.model.IModel;
 import org.apache.wicket.model.Model;
-import org.apache.wicket.spring.injection.annot.SpringBean;
 import org.apache.wicket.util.string.Strings;
 
 import com.github.openjson.JSONObject;
-import com.googlecode.wicket.jquery.core.IJQueryWidget.JQueryWidget;
-import com.googlecode.wicket.jquery.core.Options;
-import com.googlecode.wicket.jquery.ui.interaction.draggable.DraggableBehavior;
-import com.googlecode.wicket.jquery.ui.interaction.draggable.IDraggableListener;
-import com.googlecode.wicket.jquery.ui.interaction.droppable.DroppableBehavior;
-import com.googlecode.wicket.jquery.ui.interaction.droppable.IDroppableListener;
+import org.wicketstuff.jquery.core.IJQueryWidget.JQueryWidget;
+import org.wicketstuff.jquery.core.Options;
+import org.wicketstuff.jquery.ui.interaction.draggable.DraggableBehavior;
+import org.wicketstuff.jquery.ui.interaction.draggable.IDraggableListener;
+import org.wicketstuff.jquery.ui.interaction.droppable.DroppableBehavior;
+import org.wicketstuff.jquery.ui.interaction.droppable.IDroppableListener;
+
+import jakarta.inject.Inject;
 
 public class FolderPanel extends Panel implements IDraggableListener, IDroppableListener {
 	private static final long serialVersionUID = 1L;
-	private static final String CSS_CLASS_FILE = "file ";
+	private static final String CSS_CLASS_FILE = "file ps-5 ";
 	private static final String PARAM_MOD = "mod";
 	private static final String PARAM_SHIFT = "s";
 	private static final String PARAM_CTRL = "c";
 	private final StyleBehavior styleClass;
 	private final FileTreePanel treePanel;
-	@SpringBean
+
+	@Inject
 	private RecordingDao recDao;
-	@SpringBean
+	@Inject
 	private FileItemDao fileDao;
 
 	public FolderPanel(String id, final IModel<BaseFileItem> model, final FileTreePanel treePanel) {
