@@ -18,13 +18,13 @@
  */
 package org.apache.openmeetings.web.user.calendar;
 
-import static org.apache.openmeetings.util.OpenmeetingsVariables.isMyRoomsEnabled;
 import static org.apache.openmeetings.web.app.WebSession.getRights;
 import static org.apache.openmeetings.web.app.WebSession.getUserId;
 import static org.apache.openmeetings.web.common.BasePanel.EVT_CHANGE;
 import static org.apache.openmeetings.web.common.confirmation.ConfirmationHelper.newOkCancelDangerConfirm;
 import static org.apache.openmeetings.web.util.CalendarWebHelper.getDate;
 import static org.apache.openmeetings.web.util.CalendarWebHelper.getDateTime;
+import static org.apache.openmeetings.util.OpenmeetingsVariables.isMyRoomsEnabled;
 
 import java.time.LocalDateTime;
 import java.util.ArrayList;
@@ -33,7 +33,6 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 
-import org.apache.openmeetings.db.dao.basic.ConfigurationDao;
 import org.apache.openmeetings.db.dao.calendar.AppointmentDao;
 import org.apache.openmeetings.db.dao.room.RoomDao;
 import org.apache.openmeetings.db.dao.user.GroupUserDao;
@@ -71,7 +70,7 @@ import org.apache.wicket.markup.html.form.CheckBox;
 import org.apache.wicket.markup.html.form.ChoiceRenderer;
 import org.apache.wicket.markup.html.form.DropDownChoice;
 import org.apache.wicket.markup.html.form.Form;
-import org.apache.wicket.markup.html.form.IChoiceRenderer;
+import org.apache.wicket.markup.html.form.LambdaChoiceRenderer;
 import org.apache.wicket.markup.html.form.PasswordTextField;
 import org.apache.wicket.markup.html.form.Radio;
 import org.apache.wicket.markup.html.form.RadioGroup;
@@ -84,18 +83,19 @@ import org.apache.wicket.model.Model;
 import org.apache.wicket.model.PropertyModel;
 import org.apache.wicket.model.ResourceModel;
 import org.apache.wicket.model.util.CollectionModel;
-import org.apache.wicket.spring.injection.annot.SpringBean;
+
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.wicketstuff.select2.Select2MultiChoice;
 
-import com.googlecode.wicket.jquery.ui.plugins.wysiwyg.WysiwygEditor;
+import org.wicketstuff.jquery.ui.plugins.wysiwyg.WysiwygEditor;
 
 import de.agilecoders.wicket.core.markup.html.bootstrap.button.BootstrapAjaxButton;
 import de.agilecoders.wicket.core.markup.html.bootstrap.button.BootstrapAjaxLink;
 import de.agilecoders.wicket.core.markup.html.bootstrap.button.Buttons;
 import de.agilecoders.wicket.core.markup.html.bootstrap.common.NotificationPanel;
 import de.agilecoders.wicket.core.markup.html.bootstrap.dialog.Modal;
+import jakarta.inject.Inject;
 
 public class AppointmentDialog extends Modal<Appointment> {
 	private static final long serialVersionUID = 1L;
@@ -108,27 +108,26 @@ public class AppointmentDialog extends Modal<Appointment> {
 	private final CalendarPanel calendarPanel;
 	private final NotificationPanel feedback = new NotificationPanel("feedback");
 	private final WebMarkupContainer sipContainer = new WebMarkupContainer("sip-container");
-	private final RadioGroup<InviteeType> rdi = new RadioGroup<>("inviteeType", Model.of(InviteeType.user));
+	private final RadioGroup<InviteeType> rdi = new RadioGroup<>("inviteeType", Model.of(InviteeType.USER));
 	private final Select2MultiChoice<Group> groups = new Select2MultiChoice<>("groups"
 			, new CollectionModel<>(new ArrayList<>())
 			, new GroupChoiceProvider());
 	private final UserMultiChoice attendees = new UserMultiChoice("attendees", new CollectionModel<>(new ArrayList<>()));
 	private enum InviteeType {
-		user
-		, group
+		USER
+		, GROUP
 	}
-	@SpringBean
+
+	@Inject
 	private RoomDao roomDao;
-	@SpringBean
+	@Inject
 	private UserDao userDao;
-	@SpringBean
+	@Inject
 	private AppointmentDao apptDao;
-	@SpringBean
+	@Inject
 	private GroupUserDao groupUserDao;
-	@SpringBean
+	@Inject
 	private AppointmentManager apptManager;
-	@SpringBean
-	private ConfigurationDao cfgDao;
 
 	public AppointmentDialog(String id, CalendarPanel calendarPanel, CompoundPropertyModel<Appointment> model) {
 		super(id, model);
@@ -154,7 +153,7 @@ public class AppointmentDialog extends Modal<Appointment> {
 				final List<MeetingMember> mms = a.getMeetingMembers() == null ? new ArrayList<>() : a.getMeetingMembers();
 				Set<Long> currentIds = new HashSet<>();
 				List<User> users = new ArrayList<>();
-				if (InviteeType.group == rdi.getModelObject()) {
+				if (InviteeType.GROUP == rdi.getModelObject()) {
 					//lets iterate through all group users
 					for (Group g : groups.getModelObject()) {
 						for (GroupUser gu : groupUserDao.get(g.getId(), 0, Integer.MAX_VALUE)) {
@@ -214,6 +213,7 @@ public class AppointmentDialog extends Modal<Appointment> {
 				target.add(feedback);
 			}
 		});
+		save.setOutputMarkupId(true).setOutputMarkupPlaceholderTag(true);
 		addButton(enterRoom = new BootstrapAjaxLink<>(BUTTON_MARKUP_ID, null, Buttons.Type.Outline_Success, new ResourceModel("lbl.enter")) {
 			private static final long serialVersionUID = 1L;
 
@@ -243,10 +243,11 @@ public class AppointmentDialog extends Modal<Appointment> {
 		form.setModelObject(a);
 		form.start.setModelObject(getDateTime(a.getStart()));
 		form.end.setModelObject(getDateTime(a.getEnd()));
-		form.setEnabled(isOwner(a));
+		final boolean isOwner = isOwner(a);
+		form.setEnabled(isOwner);
 		log.debug(" -- setModelObjectWithAjaxTarget -- Current model {}", a);
 		if (a.getId() != null) {
-			delete.setVisible(isOwner(a));
+			delete.setVisible(isOwner);
 			enterRoom.setVisible(a.getRoom() != null);
 		} else {
 			delete.setVisible(false);
@@ -255,7 +256,7 @@ public class AppointmentDialog extends Modal<Appointment> {
 		if (a.getRoom() != null) {
 			sipContainer.replace(new Label("room.confno", a.getRoom().getConfno())).setVisible(a.getRoom().isSipEnabled());
 		}
-		save.setVisible(isOwner(a));
+		save.setVisible(isOwner);
 		target.add(form, delete, enterRoom, save);
 		super.setModelObject(a);
 	}
@@ -352,7 +353,7 @@ public class AppointmentDialog extends Modal<Appointment> {
 				cals.setEnabled(false);
 			}
 
-			rdi.setModelObject(InviteeType.user);
+			rdi.setModelObject(InviteeType.USER);
 			attendees.setModelObject(new ArrayList<>());
 			if (a.getMeetingMembers() != null) {
 				for (MeetingMember mm : a.getMeetingMembers()) {
@@ -370,20 +371,20 @@ public class AppointmentDialog extends Modal<Appointment> {
 			add(feedback.setOutputMarkupId(true));
 			//General
 			add(ownerPanel.add(owner));
-			boolean showGroups = AuthLevelUtil.hasAdminLevel(getRights());
+			boolean showGroups = AuthLevelUtil.hasAdminLevel(getRights()) || AuthLevelUtil.hasGroupAdminLevel(getRights());
 			groups.getSettings().setDropdownParent(AppointmentDialog.this.getMarkupId());
 			add(rdi.add(new AjaxFormChoiceComponentUpdatingBehavior() {
 				private static final long serialVersionUID = 1L;
 
 				@Override
 				protected void onUpdate(AjaxRequestTarget target) {
-					boolean groupsEnabled = InviteeType.group == rdi.getModelObject();
+					boolean groupsEnabled = InviteeType.GROUP == rdi.getModelObject();
 					target.add(groups.setEnabled(groupsEnabled), attendees.setEnabled(!groupsEnabled));
 				}
 			}));
 			groupContainer.add(
 				groups.setOutputMarkupId(true).setOutputMarkupPlaceholderTag(true)
-				, new Radio<>("group", Model.of(InviteeType.group))
+				, new Radio<>("group", Model.of(InviteeType.GROUP))
 			);
 			if (showGroups) {
 				groups.add(AjaxFormComponentUpdatingBehavior.onUpdate(EVT_CHANGE, target -> {
@@ -396,7 +397,7 @@ public class AppointmentDialog extends Modal<Appointment> {
 				}))
 				, groupContainer.setVisible(showGroups)
 			);
-			rdi.add(new Radio<>("user", Model.of(InviteeType.user)));
+			rdi.add(new Radio<>("user", Model.of(InviteeType.USER)));
 
 			add(new TextField<String>("location"));
 			OmWysiwygToolbar toolbar = new OmWysiwygToolbar("toolbarContainer");
@@ -422,29 +423,8 @@ public class AppointmentDialog extends Modal<Appointment> {
 			add(new DropDownChoice<>(
 					"reminder"
 					, List.of(Reminder.values())
-					, new IChoiceRenderer<Reminder>() {
-						private static final long serialVersionUID = 1L;
-
-						@Override
-						public Object getDisplayValue(Reminder art) {
-							return getString("appointment.reminder." + art.name());
-						}
-
-						@Override
-						public String getIdValue(Reminder art, int index) {
-							return art.name();
-						}
-
-						@Override
-						public Reminder getObject(String id, IModel<? extends List<? extends Reminder>> choices) {
-							for (Reminder art : choices.getObject()) {
-								if (art.name().equals(id)) {
-									return art;
-								}
-							}
-							return null;
-						}
-					}));
+					, new LambdaChoiceRenderer<>(Reminder::name, art -> getString("appointment.reminder." + art.name()))
+					));
 			add(new AjaxCheckBox("passwordProtected") {
 				private static final long serialVersionUID = 1L;
 
